@@ -1,7 +1,5 @@
-use dhat::Dhat;
-
 fn main() {
-    let _dhat = Dhat::start_ad_hoc_profiling();
+    let _profiler = dhat::Profiler::new_ad_hoc();
 
     dhat::ad_hoc_event(100);
     println!("Hello, world!");
